@@ -1,10 +1,9 @@
 list(
   rd_family_title = list(
     lookup = "Address Lookup API: ",
-    amenity = "Search amenities: ",
     geocoding = "Geocoding strings: ",
     reverse = "Reverse geocoding coordinates: ",
-    spatial = "Get spatial (\\code{sf}) objects: ",
+    spatial = "Get \\CRANpkg{sf} objects: ",
     api_management = "API Management: "
   )
 )
